@@ -3,7 +3,7 @@ import os
 from termcolor import colored as log
 
 
-db_name = os.path.abspath(os.getcwd())+"\\config.sqlite3"
+db_name = os.path.dirname(os.path.abspath(__file__))+"\\data.sqlite3"
 
 def draw():
     db = sqlite3.connect(db_name)
