@@ -3,8 +3,7 @@ import os
 from .db import delete, draw,fetch
 from .db import insert as insert_data
 
-import pathlib
-pathlib.Path(__file__).parent.resolve()
+
 
 # draw the database 
 draw()
